@@ -4,6 +4,7 @@ from .smsdotir import SmsDotIr
 from .webonesms import WebOneSms
 from .mediana import Mediana
 from .ghasedaksms import GhasedakSms
+from .farazsms import FarazSms
 
 __all__ = [
     "Kavenegar",
@@ -12,4 +13,5 @@ __all__ = [
     "MeliPayamak",
     "Mediana",
     "GhasedakSms",
+    "FarazSms",
 ]
